# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import strip_not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["TaskResource", "AsyncTaskResource"]


class TaskResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TaskResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return TaskResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TaskResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return TaskResourceWithStreamingResponse(self)

    def retrieve(
        self,
        task_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Get Agent Result

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._get(
            f"/agent/{task_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncTaskResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTaskResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncTaskResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTaskResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncTaskResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        task_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Get Agent Result

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._get(
            f"/agent/{task_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class TaskResourceWithRawResponse:
    def __init__(self, task: TaskResource) -> None:
        self._task = task

        self.retrieve = to_raw_response_wrapper(
            task.retrieve,
        )


class AsyncTaskResourceWithRawResponse:
    def __init__(self, task: AsyncTaskResource) -> None:
        self._task = task

        self.retrieve = async_to_raw_response_wrapper(
            task.retrieve,
        )


class TaskResourceWithStreamingResponse:
    def __init__(self, task: TaskResource) -> None:
        self._task = task

        self.retrieve = to_streamed_response_wrapper(
            task.retrieve,
        )


class AsyncTaskResourceWithStreamingResponse:
    def __init__(self, task: AsyncTaskResource) -> None:
        self._task = task

        self.retrieve = async_to_streamed_response_wrapper(
            task.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["User", "APIKey"]


class APIKey(BaseModel):
    created_at: Optional[datetime] = None

    key: Optional[str] = None

    name: Optional[str] = None


class User(BaseModel):
    email: str

    account_type: Optional[str] = None

    api_keys: Optional[List[APIKey]] = None

    credit_count: Optional[int] = None

    index_ids: Optional[List[str]] = None

    metadata: Optional[object] = None

    user_id: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .private import (
    PrivateResource,
    AsyncPrivateResource,
    PrivateResourceWithRawResponse,
    AsyncPrivateResourceWithRawResponse,
    PrivateResourceWithStreamingResponse,
    AsyncPrivateResourceWithStreamingResponse,
)
from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)

__all__ = [
    "PrivateResource",
    "AsyncPrivateResource",
    "PrivateResourceWithRawResponse",
    "AsyncPrivateResourceWithRawResponse",
    "PrivateResourceWithStreamingResponse",
    "AsyncPrivateResourceWithStreamingResponse",
    "AccountsResource",
    "AsyncAccountsResource",
    "AccountsResourceWithRawResponse",
    "AsyncAccountsResourceWithRawResponse",
    "AccountsResourceWithStreamingResponse",
    "AsyncAccountsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.accounts import private_update_params
from ...types.accounts.user import User

__all__ = ["PrivateResource", "AsyncPrivateResource"]


class PrivateResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PrivateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return PrivateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PrivateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return PrivateResourceWithStreamingResponse(self)

    def update(
        self,
        *,
        api_keys: Optional[Iterable[private_update_params.APIKey]] | NotGiven = NOT_GIVEN,
        metadata: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """
        Update User

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._put(
            "/accounts/private/",
            body=maybe_transform(
                {
                    "api_keys": api_keys,
                    "metadata": metadata,
                },
                private_update_params.PrivateUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """Get User"""
        return self._get(
            "/accounts/private/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )


class AsyncPrivateResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPrivateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncPrivateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPrivateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncPrivateResourceWithStreamingResponse(self)

    async def update(
        self,
        *,
        api_keys: Optional[Iterable[private_update_params.APIKey]] | NotGiven = NOT_GIVEN,
        metadata: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """
        Update User

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._put(
            "/accounts/private/",
            body=await async_maybe_transform(
                {
                    "api_keys": api_keys,
                    "metadata": metadata,
                },
                private_update_params.PrivateUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """Get User"""
        return await self._get(
            "/accounts/private/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )


class PrivateResourceWithRawResponse:
    def __init__(self, private: PrivateResource) -> None:
        self._private = private

        self.update = to_raw_response_wrapper(
            private.update,
        )
        self.list = to_raw_response_wrapper(
            private.list,
        )


class AsyncPrivateResourceWithRawResponse:
    def __init__(self, private: AsyncPrivateResource) -> None:
        self._private = private

        self.update = async_to_raw_response_wrapper(
            private.update,
        )
        self.list = async_to_raw_response_wrapper(
            private.list,
        )


class PrivateResourceWithStreamingResponse:
    def __init__(self, private: PrivateResource) -> None:
        self._private = private

        self.update = to_streamed_response_wrapper(
            private.update,
        )
        self.list = to_streamed_response_wrapper(
            private.list,
        )


class AsyncPrivateResourceWithStreamingResponse:
    def __init__(self, private: AsyncPrivateResource) -> None:
        self._private = private

        self.update = async_to_streamed_response_wrapper(
            private.update,
        )
        self.list = async_to_streamed_response_wrapper(
            private.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._types import FileTypes
from .._utils import PropertyInfo

__all__ = ["IndexFaceParams"]


class IndexFaceParams(TypedDict, total=False):
    collection_id: Required[str]

    file: Required[FileTypes]

    metadata: str

    authorization: Annotated[str, PropertyInfo(alias="Authorization")]

    index_id: Annotated[str, PropertyInfo(alias="index-id")]
    """filter by organization"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    strip_not_given,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.collections import file_full_params, file_create_params, file_update_params
from ...types.collections.fileresponse import Fileresponse
from ...types.collections.groupedfiledata import Groupedfiledata

__all__ = ["FilesResource", "AsyncFilesResource"]


class FilesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> FilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return FilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return FilesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        collection_id: str,
        filters: Optional[object] | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        randomize: bool | NotGiven = NOT_GIVEN,
        sort_by: Optional[str] | NotGiven = NOT_GIVEN,
        sort_order: Optional[Literal["asc", "desc"]] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        List Files

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/collections/files",
            body=maybe_transform(
                {
                    "collection_id": collection_id,
                    "filters": filters,
                    "page": page,
                    "page_size": page_size,
                    "randomize": randomize,
                    "sort_by": sort_by,
                    "sort_order": sort_order,
                },
                file_create_params.FileCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def retrieve(
        self,
        file_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Fileresponse:
        """
        Get File By Id

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._get(
            f"/collections/file/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Fileresponse,
        )

    def update(
        self,
        file_id: str,
        *,
        body: object,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Fileresponse:
        """
        Update File By Id

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._put(
            f"/collections/file/{file_id}",
            body=maybe_transform(body, file_update_params.FileUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Fileresponse,
        )

    def delete(
        self,
        file_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete File By Id

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._delete(
            f"/collections/file/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def full(
        self,
        file_id: str,
        *,
        modality: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Groupedfiledata:
        """
        Get File Full

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._get(
            f"/collections/file/{file_id}/full",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "modality": modality,
                        "page": page,
                        "page_size": page_size,
                    },
                    file_full_params.FileFullParams,
                ),
            ),
            cast_to=Groupedfiledata,
        )


class AsyncFilesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncFilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncFilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncFilesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        collection_id: str,
        filters: Optional[object] | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        randomize: bool | NotGiven = NOT_GIVEN,
        sort_by: Optional[str] | NotGiven = NOT_GIVEN,
        sort_order: Optional[Literal["asc", "desc"]] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        List Files

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/collections/files",
            body=await async_maybe_transform(
                {
                    "collection_id": collection_id,
                    "filters": filters,
                    "page": page,
                    "page_size": page_size,
                    "randomize": randomize,
                    "sort_by": sort_by,
                    "sort_order": sort_order,
                },
                file_create_params.FileCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def retrieve(
        self,
        file_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Fileresponse:
        """
        Get File By Id

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._get(
            f"/collections/file/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Fileresponse,
        )

    async def update(
        self,
        file_id: str,
        *,
        body: object,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Fileresponse:
        """
        Update File By Id

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._put(
            f"/collections/file/{file_id}",
            body=await async_maybe_transform(body, file_update_params.FileUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Fileresponse,
        )

    async def delete(
        self,
        file_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete File By Id

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._delete(
            f"/collections/file/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def full(
        self,
        file_id: str,
        *,
        modality: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Groupedfiledata:
        """
        Get File Full

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._get(
            f"/collections/file/{file_id}/full",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "modality": modality,
                        "page": page,
                        "page_size": page_size,
                    },
                    file_full_params.FileFullParams,
                ),
            ),
            cast_to=Groupedfiledata,
        )


class FilesResourceWithRawResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.create = to_raw_response_wrapper(
            files.create,
        )
        self.retrieve = to_raw_response_wrapper(
            files.retrieve,
        )
        self.update = to_raw_response_wrapper(
            files.update,
        )
        self.delete = to_raw_response_wrapper(
            files.delete,
        )
        self.full = to_raw_response_wrapper(
            files.full,
        )


class AsyncFilesResourceWithRawResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.create = async_to_raw_response_wrapper(
            files.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            files.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            files.update,
        )
        self.delete = async_to_raw_response_wrapper(
            files.delete,
        )
        self.full = async_to_raw_response_wrapper(
            files.full,
        )


class FilesResourceWithStreamingResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.create = to_streamed_response_wrapper(
            files.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            files.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            files.update,
        )
        self.delete = to_streamed_response_wrapper(
            files.delete,
        )
        self.full = to_streamed_response_wrapper(
            files.full,
        )


class AsyncFilesResourceWithStreamingResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.create = async_to_streamed_response_wrapper(
            files.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            files.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            files.update,
        )
        self.delete = async_to_streamed_response_wrapper(
            files.delete,
        )
        self.full = async_to_streamed_response_wrapper(
            files.full,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["FileFullParams"]


class FileFullParams(TypedDict, total=False):
    modality: str

    page: int

    page_size: int

    authorization: Annotated[str, PropertyInfo(alias="Authorization")]

    index_id: Annotated[str, PropertyInfo(alias="index-id")]
    """filter by organization"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["Groupedfiledata", "ImageDetails"]


class ImageDetails(BaseModel):
    caption: Optional[str] = None

    description: Optional[str] = None

    detect: Optional[object] = None

    text: Optional[str] = None


class Groupedfiledata(BaseModel):
    collection_id: str

    created_at: datetime

    file_id: str

    index_id: str

    metadata: object

    status: str

    url: str

    image_details: Optional[ImageDetails] = None

    video_segments: Optional[List[Dict[str, object]]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .user import User as User
from .private_update_params import PrivateUpdateParams as PrivateUpdateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .fileresponse import Fileresponse as Fileresponse
from .groupedfiledata import Groupedfiledata as Groupedfiledata
from .file_full_params import FileFullParams as FileFullParams
from .file_create_params import FileCreateParams as FileCreateParams
from .file_update_params import FileUpdateParams as FileUpdateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .taskresponse import Taskresponse as Taskresponse
from .agentresponse import Agentresponse as Agentresponse
from .index_url_params import IndexURLParams as IndexURLParams
from .embeddingresponse import Embeddingresponse as Embeddingresponse
from .index_face_params import IndexFaceParams as IndexFaceParams
from .search_url_params import SearchURLParams as SearchURLParams
from .search_text_params import SearchTextParams as SearchTextParams
from .agent_create_params import AgentCreateParams as AgentCreateParams
from .describe_url_params import DescribeURLParams as DescribeURLParams
from .embed_create_params import EmbedCreateParams as EmbedCreateParams
from .index_upload_params import IndexUploadParams as IndexUploadParams
from .search_upload_params import SearchUploadParams as SearchUploadParams
from .transcribe_url_params import TranscribeURLParams as TranscribeURLParams
from .describe_upload_params import DescribeUploadParams as DescribeUploadParams
from .collection_search_params import CollectionSearchParams as CollectionSearchParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["Embeddingresponse"]


class Embeddingresponse(BaseModel):
    embedding: List[float]
    """The embedding of the processed data."""

    elapsed_time: Optional[float] = None
    """The time taken to process the data."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.



from .._models import BaseModel

__all__ = ["Agentresponse"]


class Agentresponse(BaseModel):
    task_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = [
    "IndexURLParams",
    "ImageSettings",
    "ImageSettingsDescribe",
    "ImageSettingsDetect",
    "ImageSettingsDetectFaces",
    "ImageSettingsEmbed",
    "ImageSettingsJsonOutput",
    "ImageSettingsRead",
    "VideoSettings",
    "VideoSettingsDescribe",
    "VideoSettingsDetect",
    "VideoSettingsDetectFaces",
    "VideoSettingsEmbed",
    "VideoSettingsJsonOutput",
    "VideoSettingsRead",
    "VideoSettingsTranscribe",
]


class IndexURLParams(TypedDict, total=False):
    collection_id: Required[str]

    url: Required[str]

    image_settings: Optional[ImageSettings]

    metadata: object
    """Additional metadata associated with the file"""

    should_save: Optional[bool]
    """Whether to upload the processed file to S3"""

    video_settings: Optional[VideoSettings]

    authorization: Annotated[str, PropertyInfo(alias="Authorization")]

    index_id: Annotated[str, PropertyInfo(alias="index-id")]
    """filter by organization"""


class ImageSettingsDescribe(TypedDict, total=False):
    model_id: Optional[Literal["image-descriptor-v1"]]

    prompt: Optional[str]
    """Prompt for image description"""


class ImageSettingsDetectFaces(TypedDict, total=False):
    model_id: Optional[Literal["face-detector-v1"]]
    """Model ID for face detection"""


class ImageSettingsDetect(TypedDict, total=False):
    faces: Optional[ImageSettingsDetectFaces]
    """Settings for face detection"""


class ImageSettingsEmbed(TypedDict, total=False):
    model_id: Optional[Literal["image-embed-v1", "multimodal-v1"]]


class ImageSettingsJsonOutput(TypedDict, total=False):
    prompt: Optional[str]

    response_shape: Optional[object]


class ImageSettingsRead(TypedDict, total=False):
    json_format: object
    """JSON format for the response"""

    model_id: Optional[Literal["image-descriptor-v1"]]

    prompt: Optional[str]
    """Prompt for reading on-screen text"""


class ImageSettings(TypedDict, total=False):
    describe: Optional[ImageSettingsDescribe]

    detect: Optional[ImageSettingsDetect]

    embed: Optional[ImageSettingsEmbed]

    json_output: Optional[ImageSettingsJsonOutput]

    read: Optional[ImageSettingsRead]


class VideoSettingsDescribe(TypedDict, total=False):
    model_id: Optional[Literal["video-descriptor-v1"]]

    prompt: Optional[str]
    """Prompt for video description"""


class VideoSettingsDetectFaces(TypedDict, total=False):
    model_id: Optional[Literal["face-detector-v1"]]
    """Model ID for face detection"""


class VideoSettingsDetect(TypedDict, total=False):
    faces: Optional[VideoSettingsDetectFaces]
    """Settings for face detection"""


class VideoSettingsEmbed(TypedDict, total=False):
    contextual_text: Optional[str]

    model_id: Optional[Literal["vuse-generic-v1", "multimodal-v1"]]


class VideoSettingsJsonOutput(TypedDict, total=False):
    prompt: Optional[str]

    response_shape: Optional[object]


class VideoSettingsRead(TypedDict, total=False):
    json_format: object
    """JSON format for the response"""

    model_id: Optional[Literal["video-descriptor-v1"]]

    prompt: Optional[str]
    """Prompt for reading on-screen text"""


class VideoSettingsTranscribe(TypedDict, total=False):
    model_id: Optional[Literal["polyglot-v1"]]

    prompt: Optional[str]


class VideoSettings(TypedDict, total=False):
    describe: Optional[VideoSettingsDescribe]

    detect: Optional[VideoSettingsDetect]

    embed: Optional[VideoSettingsEmbed]

    interval_sec: int
    """Interval in seconds for processing video"""

    json_output: Optional[VideoSettingsJsonOutput]

    read: Optional[VideoSettingsRead]

    transcribe: Optional[VideoSettingsTranscribe]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from mixpeek_sdk import MixpeekSDK, AsyncMixpeekSDK
from tests.utils import assert_matches_type
from mixpeek_sdk._utils import parse_datetime
from mixpeek_sdk.types.accounts import User

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPrivate:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_update(self, client: MixpeekSDK) -> None:
        private = client.accounts.private.update()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    def test_method_update_with_all_params(self, client: MixpeekSDK) -> None:
        private = client.accounts.private.update(
            api_keys=[
                {
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "key": "key",
                    "name": "name",
                },
                {
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "key": "key",
                    "name": "name",
                },
                {
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "key": "key",
                    "name": "name",
                },
            ],
            metadata={},
        )
        assert_matches_type(User, private, path=["response"])

    @parametrize
    def test_raw_response_update(self, client: MixpeekSDK) -> None:
        response = client.accounts.private.with_raw_response.update()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = response.parse()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    def test_streaming_response_update(self, client: MixpeekSDK) -> None:
        with client.accounts.private.with_streaming_response.update() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = response.parse()
            assert_matches_type(User, private, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list(self, client: MixpeekSDK) -> None:
        private = client.accounts.private.list()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: MixpeekSDK) -> None:
        response = client.accounts.private.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = response.parse()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: MixpeekSDK) -> None:
        with client.accounts.private.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = response.parse()
            assert_matches_type(User, private, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncPrivate:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_update(self, async_client: AsyncMixpeekSDK) -> None:
        private = await async_client.accounts.private.update()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        private = await async_client.accounts.private.update(
            api_keys=[
                {
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "key": "key",
                    "name": "name",
                },
                {
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "key": "key",
                    "name": "name",
                },
                {
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "key": "key",
                    "name": "name",
                },
            ],
            metadata={},
        )
        assert_matches_type(User, private, path=["response"])

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.accounts.private.with_raw_response.update()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = await response.parse()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.accounts.private.with_streaming_response.update() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = await response.parse()
            assert_matches_type(User, private, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list(self, async_client: AsyncMixpeekSDK) -> None:
        private = await async_client.accounts.private.list()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.accounts.private.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = await response.parse()
        assert_matches_type(User, private, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.accounts.private.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = await response.parse()
            assert_matches_type(User, private, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ..types import embed_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    strip_not_given,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.embeddingresponse import Embeddingresponse

__all__ = ["EmbedResource", "AsyncEmbedResource"]


class EmbedResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmbedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return EmbedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmbedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return EmbedResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        input: str,
        input_type: Optional[Literal["text", "base64", "url"]] | NotGiven = NOT_GIVEN,
        modality: Optional[Literal["video", "image"]] | NotGiven = NOT_GIVEN,
        model_id: Optional[object] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Embeddingresponse:
        """
        Embed

        Args:
          input: The input data to be processed.

          input_type: The type of input data. Can be text, base64, or url.

          modality: The modality of the input data.

          model_id: The model to be used for processing.

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/embed/",
            body=maybe_transform(
                {
                    "input": input,
                    "input_type": input_type,
                    "modality": modality,
                    "model_id": model_id,
                },
                embed_create_params.EmbedCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Embeddingresponse,
        )


class AsyncEmbedResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmbedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncEmbedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmbedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncEmbedResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        input: str,
        input_type: Optional[Literal["text", "base64", "url"]] | NotGiven = NOT_GIVEN,
        modality: Optional[Literal["video", "image"]] | NotGiven = NOT_GIVEN,
        model_id: Optional[object] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Embeddingresponse:
        """
        Embed

        Args:
          input: The input data to be processed.

          input_type: The type of input data. Can be text, base64, or url.

          modality: The modality of the input data.

          model_id: The model to be used for processing.

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/embed/",
            body=await async_maybe_transform(
                {
                    "input": input,
                    "input_type": input_type,
                    "modality": modality,
                    "model_id": model_id,
                },
                embed_create_params.EmbedCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Embeddingresponse,
        )


class EmbedResourceWithRawResponse:
    def __init__(self, embed: EmbedResource) -> None:
        self._embed = embed

        self.create = to_raw_response_wrapper(
            embed.create,
        )


class AsyncEmbedResourceWithRawResponse:
    def __init__(self, embed: AsyncEmbedResource) -> None:
        self._embed = embed

        self.create = async_to_raw_response_wrapper(
            embed.create,
        )


class EmbedResourceWithStreamingResponse:
    def __init__(self, embed: EmbedResource) -> None:
        self._embed = embed

        self.create = to_streamed_response_wrapper(
            embed.create,
        )


class AsyncEmbedResourceWithStreamingResponse:
    def __init__(self, embed: AsyncEmbedResource) -> None:
        self._embed = embed

        self.create = async_to_streamed_response_wrapper(
            embed.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EmbedCreateParams"]


class EmbedCreateParams(TypedDict, total=False):
    input: Required[str]
    """The input data to be processed."""

    input_type: Optional[Literal["text", "base64", "url"]]
    """The type of input data. Can be text, base64, or url."""

    modality: Optional[Literal["video", "image"]]
    """The modality of the input data."""

    model_id: Optional[object]
    """The model to be used for processing."""

    authorization: Annotated[str, PropertyInfo(alias="Authorization")]

    index_id: Annotated[str, PropertyInfo(alias="index-id")]
    """filter by organization"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .files import (
    FilesResource,
    AsyncFilesResource,
    FilesResourceWithRawResponse,
    AsyncFilesResourceWithRawResponse,
    FilesResourceWithStreamingResponse,
    AsyncFilesResourceWithStreamingResponse,
)
from .collections import (
    CollectionsResource,
    AsyncCollectionsResource,
    CollectionsResourceWithRawResponse,
    AsyncCollectionsResourceWithRawResponse,
    CollectionsResourceWithStreamingResponse,
    AsyncCollectionsResourceWithStreamingResponse,
)

__all__ = [
    "FilesResource",
    "AsyncFilesResource",
    "FilesResourceWithRawResponse",
    "AsyncFilesResourceWithRawResponse",
    "FilesResourceWithStreamingResponse",
    "AsyncFilesResourceWithStreamingResponse",
    "CollectionsResource",
    "AsyncCollectionsResource",
    "CollectionsResourceWithRawResponse",
    "AsyncCollectionsResourceWithRawResponse",
    "CollectionsResourceWithStreamingResponse",
    "AsyncCollectionsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["FileCreateParams"]


class FileCreateParams(TypedDict, total=False):
    collection_id: Required[str]

    filters: Optional[object]

    page: int

    page_size: int

    randomize: bool

    sort_by: Optional[str]

    sort_order: Optional[Literal["asc", "desc"]]

    authorization: Annotated[str, PropertyInfo(alias="Authorization")]

    index_id: Annotated[str, PropertyInfo(alias="index-id")]
    """filter by organization"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .read import (
    ReadResource,
    AsyncReadResource,
    ReadResourceWithRawResponse,
    AsyncReadResourceWithRawResponse,
    ReadResourceWithStreamingResponse,
    AsyncReadResourceWithStreamingResponse,
)
from .agent import (
    AgentResource,
    AsyncAgentResource,
    AgentResourceWithRawResponse,
    AsyncAgentResourceWithRawResponse,
    AgentResourceWithStreamingResponse,
    AsyncAgentResourceWithStreamingResponse,
)
from .embed import (
    EmbedResource,
    AsyncEmbedResource,
    EmbedResourceWithRawResponse,
    AsyncEmbedResourceWithRawResponse,
    EmbedResourceWithStreamingResponse,
    AsyncEmbedResourceWithStreamingResponse,
)
from .index import (
    IndexResource,
    AsyncIndexResource,
    IndexResourceWithRawResponse,
    AsyncIndexResourceWithRawResponse,
    IndexResourceWithStreamingResponse,
    AsyncIndexResourceWithStreamingResponse,
)
from .tasks import (
    TasksResource,
    AsyncTasksResource,
    TasksResourceWithRawResponse,
    AsyncTasksResourceWithRawResponse,
    TasksResourceWithStreamingResponse,
    AsyncTasksResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .accounts import (
    AccountsResource,
    AsyncAccountsResource,
    AccountsResourceWithRawResponse,
    AsyncAccountsResourceWithRawResponse,
    AccountsResourceWithStreamingResponse,
    AsyncAccountsResourceWithStreamingResponse,
)
from .describe import (
    DescribeResource,
    AsyncDescribeResource,
    DescribeResourceWithRawResponse,
    AsyncDescribeResourceWithRawResponse,
    DescribeResourceWithStreamingResponse,
    AsyncDescribeResourceWithStreamingResponse,
)
from .recognize import (
    RecognizeResource,
    AsyncRecognizeResource,
    RecognizeResourceWithRawResponse,
    AsyncRecognizeResourceWithRawResponse,
    RecognizeResourceWithStreamingResponse,
    AsyncRecognizeResourceWithStreamingResponse,
)
from .transcribe import (
    TranscribeResource,
    AsyncTranscribeResource,
    TranscribeResourceWithRawResponse,
    AsyncTranscribeResourceWithRawResponse,
    TranscribeResourceWithStreamingResponse,
    AsyncTranscribeResourceWithStreamingResponse,
)
from .collections import (
    CollectionsResource,
    AsyncCollectionsResource,
    CollectionsResourceWithRawResponse,
    AsyncCollectionsResourceWithRawResponse,
    CollectionsResourceWithStreamingResponse,
    AsyncCollectionsResourceWithStreamingResponse,
)

__all__ = [
    "AccountsResource",
    "AsyncAccountsResource",
    "AccountsResourceWithRawResponse",
    "AsyncAccountsResourceWithRawResponse",
    "AccountsResourceWithStreamingResponse",
    "AsyncAccountsResourceWithStreamingResponse",
    "DescribeResource",
    "AsyncDescribeResource",
    "DescribeResourceWithRawResponse",
    "AsyncDescribeResourceWithRawResponse",
    "DescribeResourceWithStreamingResponse",
    "AsyncDescribeResourceWithStreamingResponse",
    "EmbedResource",
    "AsyncEmbedResource",
    "EmbedResourceWithRawResponse",
    "AsyncEmbedResourceWithRawResponse",
    "EmbedResourceWithStreamingResponse",
    "AsyncEmbedResourceWithStreamingResponse",
    "TranscribeResource",
    "AsyncTranscribeResource",
    "TranscribeResourceWithRawResponse",
    "AsyncTranscribeResourceWithRawResponse",
    "TranscribeResourceWithStreamingResponse",
    "AsyncTranscribeResourceWithStreamingResponse",
    "ReadResource",
    "AsyncReadResource",
    "ReadResourceWithRawResponse",
    "AsyncReadResourceWithRawResponse",
    "ReadResourceWithStreamingResponse",
    "AsyncReadResourceWithStreamingResponse",
    "RecognizeResource",
    "AsyncRecognizeResource",
    "RecognizeResourceWithRawResponse",
    "AsyncRecognizeResourceWithRawResponse",
    "RecognizeResourceWithStreamingResponse",
    "AsyncRecognizeResourceWithStreamingResponse",
    "AgentResource",
    "AsyncAgentResource",
    "AgentResourceWithRawResponse",
    "AsyncAgentResourceWithRawResponse",
    "AgentResourceWithStreamingResponse",
    "AsyncAgentResourceWithStreamingResponse",
    "IndexResource",
    "AsyncIndexResource",
    "IndexResourceWithRawResponse",
    "AsyncIndexResourceWithRawResponse",
    "IndexResourceWithStreamingResponse",
    "AsyncIndexResourceWithStreamingResponse",
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
    "CollectionsResource",
    "AsyncCollectionsResource",
    "CollectionsResourceWithRawResponse",
    "AsyncCollectionsResourceWithRawResponse",
    "CollectionsResourceWithStreamingResponse",
    "AsyncCollectionsResourceWithStreamingResponse",
    "TasksResource",
    "AsyncTasksResource",
    "TasksResourceWithRawResponse",
    "AsyncTasksResourceWithRawResponse",
    "TasksResourceWithStreamingResponse",
    "AsyncTasksResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, Optional, cast

import httpx

from ..types import search_url_params, search_text_params, search_upload_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven, FileTypes
from .._utils import (
    extract_files,
    maybe_transform,
    strip_not_given,
    deepcopy_minimal,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["SearchResource", "AsyncSearchResource"]


class SearchResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return SearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return SearchResourceWithStreamingResponse(self)

    def text(
        self,
        *,
        input: str,
        filters: object | NotGiven = NOT_GIVEN,
        group_by_file: bool | NotGiven = NOT_GIVEN,
        input_type: Optional[str] | NotGiven = NOT_GIVEN,
        modality: Optional[str] | NotGiven = NOT_GIVEN,
        model_id: Optional[str] | NotGiven = NOT_GIVEN,
        pagination: search_text_params.Pagination | NotGiven = NOT_GIVEN,
        source: Optional[str] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search

        Args:
          input: url, text, or base64 input

          filters: Additional filters for the search

          group_by_file: Whether to group search results by file

          pagination: Pagination parameters

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/search/text",
            body=maybe_transform(
                {
                    "input": input,
                    "filters": filters,
                    "group_by_file": group_by_file,
                    "input_type": input_type,
                    "modality": modality,
                    "model_id": model_id,
                    "pagination": pagination,
                    "source": source,
                },
                search_text_params.SearchTextParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def upload(
        self,
        *,
        file: FileTypes,
        filters: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search Video

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        body = deepcopy_minimal(
            {
                "file": file,
                "filters": filters,
                "page": page,
                "page_size": page_size,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/search/upload",
            body=maybe_transform(body, search_upload_params.SearchUploadParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def url(
        self,
        *,
        input: str,
        filters: object | NotGiven = NOT_GIVEN,
        group_by_file: bool | NotGiven = NOT_GIVEN,
        input_type: Optional[str] | NotGiven = NOT_GIVEN,
        modality: Optional[str] | NotGiven = NOT_GIVEN,
        model_id: Optional[str] | NotGiven = NOT_GIVEN,
        pagination: search_url_params.Pagination | NotGiven = NOT_GIVEN,
        source: Optional[str] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search Url

        Args:
          input: url, text, or base64 input

          filters: Additional filters for the search

          group_by_file: Whether to group search results by file

          pagination: Pagination parameters

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/search/url",
            body=maybe_transform(
                {
                    "input": input,
                    "filters": filters,
                    "group_by_file": group_by_file,
                    "input_type": input_type,
                    "modality": modality,
                    "model_id": model_id,
                    "pagination": pagination,
                    "source": source,
                },
                search_url_params.SearchURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncSearchResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncSearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncSearchResourceWithStreamingResponse(self)

    async def text(
        self,
        *,
        input: str,
        filters: object | NotGiven = NOT_GIVEN,
        group_by_file: bool | NotGiven = NOT_GIVEN,
        input_type: Optional[str] | NotGiven = NOT_GIVEN,
        modality: Optional[str] | NotGiven = NOT_GIVEN,
        model_id: Optional[str] | NotGiven = NOT_GIVEN,
        pagination: search_text_params.Pagination | NotGiven = NOT_GIVEN,
        source: Optional[str] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search

        Args:
          input: url, text, or base64 input

          filters: Additional filters for the search

          group_by_file: Whether to group search results by file

          pagination: Pagination parameters

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/search/text",
            body=await async_maybe_transform(
                {
                    "input": input,
                    "filters": filters,
                    "group_by_file": group_by_file,
                    "input_type": input_type,
                    "modality": modality,
                    "model_id": model_id,
                    "pagination": pagination,
                    "source": source,
                },
                search_text_params.SearchTextParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def upload(
        self,
        *,
        file: FileTypes,
        filters: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search Video

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        body = deepcopy_minimal(
            {
                "file": file,
                "filters": filters,
                "page": page,
                "page_size": page_size,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/search/upload",
            body=await async_maybe_transform(body, search_upload_params.SearchUploadParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def url(
        self,
        *,
        input: str,
        filters: object | NotGiven = NOT_GIVEN,
        group_by_file: bool | NotGiven = NOT_GIVEN,
        input_type: Optional[str] | NotGiven = NOT_GIVEN,
        modality: Optional[str] | NotGiven = NOT_GIVEN,
        model_id: Optional[str] | NotGiven = NOT_GIVEN,
        pagination: search_url_params.Pagination | NotGiven = NOT_GIVEN,
        source: Optional[str] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search Url

        Args:
          input: url, text, or base64 input

          filters: Additional filters for the search

          group_by_file: Whether to group search results by file

          pagination: Pagination parameters

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/search/url",
            body=await async_maybe_transform(
                {
                    "input": input,
                    "filters": filters,
                    "group_by_file": group_by_file,
                    "input_type": input_type,
                    "modality": modality,
                    "model_id": model_id,
                    "pagination": pagination,
                    "source": source,
                },
                search_url_params.SearchURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class SearchResourceWithRawResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.text = to_raw_response_wrapper(
            search.text,
        )
        self.upload = to_raw_response_wrapper(
            search.upload,
        )
        self.url = to_raw_response_wrapper(
            search.url,
        )


class AsyncSearchResourceWithRawResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.text = async_to_raw_response_wrapper(
            search.text,
        )
        self.upload = async_to_raw_response_wrapper(
            search.upload,
        )
        self.url = async_to_raw_response_wrapper(
            search.url,
        )


class SearchResourceWithStreamingResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.text = to_streamed_response_wrapper(
            search.text,
        )
        self.upload = to_streamed_response_wrapper(
            search.upload,
        )
        self.url = to_streamed_response_wrapper(
            search.url,
        )


class AsyncSearchResourceWithStreamingResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.text = async_to_streamed_response_wrapper(
            search.text,
        )
        self.upload = async_to_streamed_response_wrapper(
            search.upload,
        )
        self.url = async_to_streamed_response_wrapper(
            search.url,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from .files import (
    FilesResource,
    AsyncFilesResource,
    FilesResourceWithRawResponse,
    AsyncFilesResourceWithRawResponse,
    FilesResourceWithStreamingResponse,
    AsyncFilesResourceWithStreamingResponse,
)
from ...types import collection_search_params
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    strip_not_given,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["CollectionsResource", "AsyncCollectionsResource"]


class CollectionsResource(SyncAPIResource):
    @cached_property
    def files(self) -> FilesResource:
        return FilesResource(self._client)

    @cached_property
    def with_raw_response(self) -> CollectionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return CollectionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CollectionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return CollectionsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        List Collections

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._get(
            "/collections/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def delete(
        self,
        collection_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete Collection

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not collection_id:
            raise ValueError(f"Expected a non-empty value for `collection_id` but received {collection_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._delete(
            f"/collections/{collection_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def search(
        self,
        *,
        collection_id: str,
        query: str,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        sort_by: Optional[str] | NotGiven = NOT_GIVEN,
        sort_order: Optional[Literal["asc", "desc"]] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search Files

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/collections/search",
            body=maybe_transform(
                {
                    "collection_id": collection_id,
                    "query": query,
                    "page": page,
                    "page_size": page_size,
                    "sort_by": sort_by,
                    "sort_order": sort_order,
                },
                collection_search_params.CollectionSearchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncCollectionsResource(AsyncAPIResource):
    @cached_property
    def files(self) -> AsyncFilesResource:
        return AsyncFilesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncCollectionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncCollectionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCollectionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncCollectionsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        List Collections

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._get(
            "/collections/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def delete(
        self,
        collection_id: str,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete Collection

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not collection_id:
            raise ValueError(f"Expected a non-empty value for `collection_id` but received {collection_id!r}")
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._delete(
            f"/collections/{collection_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def search(
        self,
        *,
        collection_id: str,
        query: str,
        page: int | NotGiven = NOT_GIVEN,
        page_size: int | NotGiven = NOT_GIVEN,
        sort_by: Optional[str] | NotGiven = NOT_GIVEN,
        sort_order: Optional[Literal["asc", "desc"]] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Search Files

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/collections/search",
            body=await async_maybe_transform(
                {
                    "collection_id": collection_id,
                    "query": query,
                    "page": page,
                    "page_size": page_size,
                    "sort_by": sort_by,
                    "sort_order": sort_order,
                },
                collection_search_params.CollectionSearchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class CollectionsResourceWithRawResponse:
    def __init__(self, collections: CollectionsResource) -> None:
        self._collections = collections

        self.list = to_raw_response_wrapper(
            collections.list,
        )
        self.delete = to_raw_response_wrapper(
            collections.delete,
        )
        self.search = to_raw_response_wrapper(
            collections.search,
        )

    @cached_property
    def files(self) -> FilesResourceWithRawResponse:
        return FilesResourceWithRawResponse(self._collections.files)


class AsyncCollectionsResourceWithRawResponse:
    def __init__(self, collections: AsyncCollectionsResource) -> None:
        self._collections = collections

        self.list = async_to_raw_response_wrapper(
            collections.list,
        )
        self.delete = async_to_raw_response_wrapper(
            collections.delete,
        )
        self.search = async_to_raw_response_wrapper(
            collections.search,
        )

    @cached_property
    def files(self) -> AsyncFilesResourceWithRawResponse:
        return AsyncFilesResourceWithRawResponse(self._collections.files)


class CollectionsResourceWithStreamingResponse:
    def __init__(self, collections: CollectionsResource) -> None:
        self._collections = collections

        self.list = to_streamed_response_wrapper(
            collections.list,
        )
        self.delete = to_streamed_response_wrapper(
            collections.delete,
        )
        self.search = to_streamed_response_wrapper(
            collections.search,
        )

    @cached_property
    def files(self) -> FilesResourceWithStreamingResponse:
        return FilesResourceWithStreamingResponse(self._collections.files)


class AsyncCollectionsResourceWithStreamingResponse:
    def __init__(self, collections: AsyncCollectionsResource) -> None:
        self._collections = collections

        self.list = async_to_streamed_response_wrapper(
            collections.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            collections.delete,
        )
        self.search = async_to_streamed_response_wrapper(
            collections.search,
        )

    @cached_property
    def files(self) -> AsyncFilesResourceWithStreamingResponse:
        return AsyncFilesResourceWithStreamingResponse(self._collections.files)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["FileUpdateParams"]


class FileUpdateParams(TypedDict, total=False):
    body: Required[object]

    authorization: Annotated[str, PropertyInfo(alias="Authorization")]

    index_id: Annotated[str, PropertyInfo(alias="index-id")]
    """filter by organization"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from mixpeek_sdk import MixpeekSDK, AsyncMixpeekSDK
from tests.utils import assert_matches_type
from mixpeek_sdk.types import Embeddingresponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEmbed:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: MixpeekSDK) -> None:
        embed = client.embed.create(
            input="input",
        )
        assert_matches_type(Embeddingresponse, embed, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: MixpeekSDK) -> None:
        embed = client.embed.create(
            input="input",
            input_type="text",
            modality="video",
            model_id={},
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(Embeddingresponse, embed, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: MixpeekSDK) -> None:
        response = client.embed.with_raw_response.create(
            input="input",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        embed = response.parse()
        assert_matches_type(Embeddingresponse, embed, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: MixpeekSDK) -> None:
        with client.embed.with_streaming_response.create(
            input="input",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            embed = response.parse()
            assert_matches_type(Embeddingresponse, embed, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncEmbed:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncMixpeekSDK) -> None:
        embed = await async_client.embed.create(
            input="input",
        )
        assert_matches_type(Embeddingresponse, embed, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        embed = await async_client.embed.create(
            input="input",
            input_type="text",
            modality="video",
            model_id={},
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(Embeddingresponse, embed, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.embed.with_raw_response.create(
            input="input",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        embed = await response.parse()
        assert_matches_type(Embeddingresponse, embed, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.embed.with_streaming_response.create(
            input="input",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            embed = await response.parse()
            assert_matches_type(Embeddingresponse, embed, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, Optional, cast

import httpx

from ..types import index_url_params, index_face_params, index_upload_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven, FileTypes
from .._utils import (
    extract_files,
    maybe_transform,
    strip_not_given,
    deepcopy_minimal,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["IndexResource", "AsyncIndexResource"]


class IndexResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IndexResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return IndexResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IndexResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return IndexResourceWithStreamingResponse(self)

    def face(
        self,
        *,
        collection_id: str,
        file: FileTypes,
        metadata: str | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Index Face

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        body = deepcopy_minimal(
            {
                "collection_id": collection_id,
                "file": file,
                "metadata": metadata,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/index/face",
            body=maybe_transform(body, index_face_params.IndexFaceParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def upload(
        self,
        *,
        collection_id: str,
        file: FileTypes,
        image_settings: str | NotGiven = NOT_GIVEN,
        metadata: str | NotGiven = NOT_GIVEN,
        video_settings: str | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Index Upload

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        body = deepcopy_minimal(
            {
                "collection_id": collection_id,
                "file": file,
                "image_settings": image_settings,
                "metadata": metadata,
                "video_settings": video_settings,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/index/upload",
            body=maybe_transform(body, index_upload_params.IndexUploadParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def url(
        self,
        *,
        collection_id: str,
        url: str,
        image_settings: Optional[index_url_params.ImageSettings] | NotGiven = NOT_GIVEN,
        metadata: object | NotGiven = NOT_GIVEN,
        should_save: Optional[bool] | NotGiven = NOT_GIVEN,
        video_settings: Optional[index_url_params.VideoSettings] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Index Url

        Args:
          metadata: Additional metadata associated with the file

          should_save: Whether to upload the processed file to S3

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/index/url",
            body=maybe_transform(
                {
                    "collection_id": collection_id,
                    "url": url,
                    "image_settings": image_settings,
                    "metadata": metadata,
                    "should_save": should_save,
                    "video_settings": video_settings,
                },
                index_url_params.IndexURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncIndexResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIndexResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncIndexResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIndexResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncIndexResourceWithStreamingResponse(self)

    async def face(
        self,
        *,
        collection_id: str,
        file: FileTypes,
        metadata: str | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Index Face

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        body = deepcopy_minimal(
            {
                "collection_id": collection_id,
                "file": file,
                "metadata": metadata,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/index/face",
            body=await async_maybe_transform(body, index_face_params.IndexFaceParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def upload(
        self,
        *,
        collection_id: str,
        file: FileTypes,
        image_settings: str | NotGiven = NOT_GIVEN,
        metadata: str | NotGiven = NOT_GIVEN,
        video_settings: str | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Index Upload

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        body = deepcopy_minimal(
            {
                "collection_id": collection_id,
                "file": file,
                "image_settings": image_settings,
                "metadata": metadata,
                "video_settings": video_settings,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/index/upload",
            body=await async_maybe_transform(body, index_upload_params.IndexUploadParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def url(
        self,
        *,
        collection_id: str,
        url: str,
        image_settings: Optional[index_url_params.ImageSettings] | NotGiven = NOT_GIVEN,
        metadata: object | NotGiven = NOT_GIVEN,
        should_save: Optional[bool] | NotGiven = NOT_GIVEN,
        video_settings: Optional[index_url_params.VideoSettings] | NotGiven = NOT_GIVEN,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Index Url

        Args:
          metadata: Additional metadata associated with the file

          should_save: Whether to upload the processed file to S3

          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/index/url",
            body=await async_maybe_transform(
                {
                    "collection_id": collection_id,
                    "url": url,
                    "image_settings": image_settings,
                    "metadata": metadata,
                    "should_save": should_save,
                    "video_settings": video_settings,
                },
                index_url_params.IndexURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class IndexResourceWithRawResponse:
    def __init__(self, index: IndexResource) -> None:
        self._index = index

        self.face = to_raw_response_wrapper(
            index.face,
        )
        self.upload = to_raw_response_wrapper(
            index.upload,
        )
        self.url = to_raw_response_wrapper(
            index.url,
        )


class AsyncIndexResourceWithRawResponse:
    def __init__(self, index: AsyncIndexResource) -> None:
        self._index = index

        self.face = async_to_raw_response_wrapper(
            index.face,
        )
        self.upload = async_to_raw_response_wrapper(
            index.upload,
        )
        self.url = async_to_raw_response_wrapper(
            index.url,
        )


class IndexResourceWithStreamingResponse:
    def __init__(self, index: IndexResource) -> None:
        self._index = index

        self.face = to_streamed_response_wrapper(
            index.face,
        )
        self.upload = to_streamed_response_wrapper(
            index.upload,
        )
        self.url = to_streamed_response_wrapper(
            index.url,
        )


class AsyncIndexResourceWithStreamingResponse:
    def __init__(self, index: AsyncIndexResource) -> None:
        self._index = index

        self.face = async_to_streamed_response_wrapper(
            index.face,
        )
        self.upload = async_to_streamed_response_wrapper(
            index.upload,
        )
        self.url = async_to_streamed_response_wrapper(
            index.url,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime

from ..._models import BaseModel

__all__ = ["Fileresponse"]


class Fileresponse(BaseModel):
    collection_id: str

    created_at: datetime

    file_id: str

    index_id: str

    metadata: object

    status: str

    url: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from mixpeek_sdk import MixpeekSDK, AsyncMixpeekSDK
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestIndex:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_face(self, client: MixpeekSDK) -> None:
        index = client.index.face(
            collection_id="collection_id",
            file=b"raw file contents",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_method_face_with_all_params(self, client: MixpeekSDK) -> None:
        index = client.index.face(
            collection_id="collection_id",
            file=b"raw file contents",
            metadata="metadata",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_raw_response_face(self, client: MixpeekSDK) -> None:
        response = client.index.with_raw_response.face(
            collection_id="collection_id",
            file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        index = response.parse()
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_streaming_response_face(self, client: MixpeekSDK) -> None:
        with client.index.with_streaming_response.face(
            collection_id="collection_id",
            file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            index = response.parse()
            assert_matches_type(object, index, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_upload(self, client: MixpeekSDK) -> None:
        index = client.index.upload(
            collection_id="collection_id",
            file=b"raw file contents",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_method_upload_with_all_params(self, client: MixpeekSDK) -> None:
        index = client.index.upload(
            collection_id="collection_id",
            file=b"raw file contents",
            image_settings="image_settings",
            metadata="metadata",
            video_settings="video_settings",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_raw_response_upload(self, client: MixpeekSDK) -> None:
        response = client.index.with_raw_response.upload(
            collection_id="collection_id",
            file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        index = response.parse()
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_streaming_response_upload(self, client: MixpeekSDK) -> None:
        with client.index.with_streaming_response.upload(
            collection_id="collection_id",
            file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            index = response.parse()
            assert_matches_type(object, index, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_url(self, client: MixpeekSDK) -> None:
        index = client.index.url(
            collection_id="collection_id",
            url="url",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_method_url_with_all_params(self, client: MixpeekSDK) -> None:
        index = client.index.url(
            collection_id="collection_id",
            url="url",
            image_settings={
                "describe": {
                    "model_id": "image-descriptor-v1",
                    "prompt": "prompt",
                },
                "detect": {"faces": {"model_id": "face-detector-v1"}},
                "embed": {"model_id": "image-embed-v1"},
                "json_output": {
                    "prompt": "prompt",
                    "response_shape": {},
                },
                "read": {
                    "json_format": {},
                    "model_id": "image-descriptor-v1",
                    "prompt": "prompt",
                },
            },
            metadata={},
            should_save=True,
            video_settings={
                "describe": {
                    "model_id": "video-descriptor-v1",
                    "prompt": "prompt",
                },
                "detect": {"faces": {"model_id": "face-detector-v1"}},
                "embed": {
                    "contextual_text": "contextual_text",
                    "model_id": "vuse-generic-v1",
                },
                "interval_sec": 0,
                "json_output": {
                    "prompt": "prompt",
                    "response_shape": {},
                },
                "read": {
                    "json_format": {},
                    "model_id": "video-descriptor-v1",
                    "prompt": "prompt",
                },
                "transcribe": {
                    "model_id": "polyglot-v1",
                    "prompt": "prompt",
                },
            },
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_raw_response_url(self, client: MixpeekSDK) -> None:
        response = client.index.with_raw_response.url(
            collection_id="collection_id",
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        index = response.parse()
        assert_matches_type(object, index, path=["response"])

    @parametrize
    def test_streaming_response_url(self, client: MixpeekSDK) -> None:
        with client.index.with_streaming_response.url(
            collection_id="collection_id",
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            index = response.parse()
            assert_matches_type(object, index, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncIndex:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_face(self, async_client: AsyncMixpeekSDK) -> None:
        index = await async_client.index.face(
            collection_id="collection_id",
            file=b"raw file contents",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_method_face_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        index = await async_client.index.face(
            collection_id="collection_id",
            file=b"raw file contents",
            metadata="metadata",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_raw_response_face(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.index.with_raw_response.face(
            collection_id="collection_id",
            file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        index = await response.parse()
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_streaming_response_face(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.index.with_streaming_response.face(
            collection_id="collection_id",
            file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            index = await response.parse()
            assert_matches_type(object, index, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_upload(self, async_client: AsyncMixpeekSDK) -> None:
        index = await async_client.index.upload(
            collection_id="collection_id",
            file=b"raw file contents",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_method_upload_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        index = await async_client.index.upload(
            collection_id="collection_id",
            file=b"raw file contents",
            image_settings="image_settings",
            metadata="metadata",
            video_settings="video_settings",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_raw_response_upload(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.index.with_raw_response.upload(
            collection_id="collection_id",
            file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        index = await response.parse()
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_streaming_response_upload(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.index.with_streaming_response.upload(
            collection_id="collection_id",
            file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            index = await response.parse()
            assert_matches_type(object, index, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_url(self, async_client: AsyncMixpeekSDK) -> None:
        index = await async_client.index.url(
            collection_id="collection_id",
            url="url",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_method_url_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        index = await async_client.index.url(
            collection_id="collection_id",
            url="url",
            image_settings={
                "describe": {
                    "model_id": "image-descriptor-v1",
                    "prompt": "prompt",
                },
                "detect": {"faces": {"model_id": "face-detector-v1"}},
                "embed": {"model_id": "image-embed-v1"},
                "json_output": {
                    "prompt": "prompt",
                    "response_shape": {},
                },
                "read": {
                    "json_format": {},
                    "model_id": "image-descriptor-v1",
                    "prompt": "prompt",
                },
            },
            metadata={},
            should_save=True,
            video_settings={
                "describe": {
                    "model_id": "video-descriptor-v1",
                    "prompt": "prompt",
                },
                "detect": {"faces": {"model_id": "face-detector-v1"}},
                "embed": {
                    "contextual_text": "contextual_text",
                    "model_id": "vuse-generic-v1",
                },
                "interval_sec": 0,
                "json_output": {
                    "prompt": "prompt",
                    "response_shape": {},
                },
                "read": {
                    "json_format": {},
                    "model_id": "video-descriptor-v1",
                    "prompt": "prompt",
                },
                "transcribe": {
                    "model_id": "polyglot-v1",
                    "prompt": "prompt",
                },
            },
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_raw_response_url(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.index.with_raw_response.url(
            collection_id="collection_id",
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        index = await response.parse()
        assert_matches_type(object, index, path=["response"])

    @parametrize
    async def test_streaming_response_url(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.index.with_streaming_response.url(
            collection_id="collection_id",
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            index = await response.parse()
            assert_matches_type(object, index, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .task import (
    TaskResource,
    AsyncTaskResource,
    TaskResourceWithRawResponse,
    AsyncTaskResourceWithRawResponse,
    TaskResourceWithStreamingResponse,
    AsyncTaskResourceWithStreamingResponse,
)
from .agent import (
    AgentResource,
    AsyncAgentResource,
    AgentResourceWithRawResponse,
    AsyncAgentResourceWithRawResponse,
    AgentResourceWithStreamingResponse,
    AsyncAgentResourceWithStreamingResponse,
)

__all__ = [
    "TaskResource",
    "AsyncTaskResource",
    "TaskResourceWithRawResponse",
    "AsyncTaskResourceWithRawResponse",
    "TaskResourceWithStreamingResponse",
    "AsyncTaskResourceWithStreamingResponse",
    "AgentResource",
    "AsyncAgentResource",
    "AgentResourceWithRawResponse",
    "AsyncAgentResourceWithRawResponse",
    "AgentResourceWithStreamingResponse",
    "AsyncAgentResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from mixpeek_sdk import MixpeekSDK, AsyncMixpeekSDK
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSearch:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_text(self, client: MixpeekSDK) -> None:
        search = client.search.text(
            input="input",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_method_text_with_all_params(self, client: MixpeekSDK) -> None:
        search = client.search.text(
            input="input",
            filters={},
            group_by_file=True,
            input_type="input_type",
            modality="modality",
            model_id="model_id",
            pagination={
                "page": 1,
                "page_size": 1,
            },
            source="source",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_raw_response_text(self, client: MixpeekSDK) -> None:
        response = client.search.with_raw_response.text(
            input="input",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_streaming_response_text(self, client: MixpeekSDK) -> None:
        with client.search.with_streaming_response.text(
            input="input",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(object, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_upload(self, client: MixpeekSDK) -> None:
        search = client.search.upload(
            file=b"raw file contents",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_method_upload_with_all_params(self, client: MixpeekSDK) -> None:
        search = client.search.upload(
            file=b"raw file contents",
            filters="filters",
            page=0,
            page_size=0,
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_raw_response_upload(self, client: MixpeekSDK) -> None:
        response = client.search.with_raw_response.upload(
            file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_streaming_response_upload(self, client: MixpeekSDK) -> None:
        with client.search.with_streaming_response.upload(
            file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(object, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_url(self, client: MixpeekSDK) -> None:
        search = client.search.url(
            input="input",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_method_url_with_all_params(self, client: MixpeekSDK) -> None:
        search = client.search.url(
            input="input",
            filters={},
            group_by_file=True,
            input_type="input_type",
            modality="modality",
            model_id="model_id",
            pagination={
                "page": 1,
                "page_size": 1,
            },
            source="source",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_raw_response_url(self, client: MixpeekSDK) -> None:
        response = client.search.with_raw_response.url(
            input="input",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(object, search, path=["response"])

    @parametrize
    def test_streaming_response_url(self, client: MixpeekSDK) -> None:
        with client.search.with_streaming_response.url(
            input="input",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(object, search, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSearch:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_text(self, async_client: AsyncMixpeekSDK) -> None:
        search = await async_client.search.text(
            input="input",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_method_text_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        search = await async_client.search.text(
            input="input",
            filters={},
            group_by_file=True,
            input_type="input_type",
            modality="modality",
            model_id="model_id",
            pagination={
                "page": 1,
                "page_size": 1,
            },
            source="source",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_raw_response_text(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.search.with_raw_response.text(
            input="input",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_streaming_response_text(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.search.with_streaming_response.text(
            input="input",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(object, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_upload(self, async_client: AsyncMixpeekSDK) -> None:
        search = await async_client.search.upload(
            file=b"raw file contents",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_method_upload_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        search = await async_client.search.upload(
            file=b"raw file contents",
            filters="filters",
            page=0,
            page_size=0,
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_raw_response_upload(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.search.with_raw_response.upload(
            file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_streaming_response_upload(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.search.with_streaming_response.upload(
            file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(object, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_url(self, async_client: AsyncMixpeekSDK) -> None:
        search = await async_client.search.url(
            input="input",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_method_url_with_all_params(self, async_client: AsyncMixpeekSDK) -> None:
        search = await async_client.search.url(
            input="input",
            filters={},
            group_by_file=True,
            input_type="input_type",
            modality="modality",
            model_id="model_id",
            pagination={
                "page": 1,
                "page_size": 1,
            },
            source="source",
            authorization="Authorization",
            index_id="index-id",
        )
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_raw_response_url(self, async_client: AsyncMixpeekSDK) -> None:
        response = await async_client.search.with_raw_response.url(
            input="input",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(object, search, path=["response"])

    @parametrize
    async def test_streaming_response_url(self, async_client: AsyncMixpeekSDK) -> None:
        async with async_client.search.with_streaming_response.url(
            input="input",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(object, search, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable, Optional
from datetime import datetime
from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["PrivateUpdateParams", "APIKey"]


class PrivateUpdateParams(TypedDict, total=False):
    api_keys: Optional[Iterable[APIKey]]

    metadata: Optional[object]


class APIKey(TypedDict, total=False):
    created_at: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    key: str

    name: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .private import (
    PrivateResource,
    AsyncPrivateResource,
    PrivateResourceWithRawResponse,
    AsyncPrivateResourceWithRawResponse,
    PrivateResourceWithStreamingResponse,
    AsyncPrivateResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["AccountsResource", "AsyncAccountsResource"]


class AccountsResource(SyncAPIResource):
    @cached_property
    def private(self) -> PrivateResource:
        return PrivateResource(self._client)

    @cached_property
    def with_raw_response(self) -> AccountsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AccountsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AccountsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AccountsResourceWithStreamingResponse(self)


class AsyncAccountsResource(AsyncAPIResource):
    @cached_property
    def private(self) -> AsyncPrivateResource:
        return AsyncPrivateResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAccountsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncAccountsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAccountsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncAccountsResourceWithStreamingResponse(self)


class AccountsResourceWithRawResponse:
    def __init__(self, accounts: AccountsResource) -> None:
        self._accounts = accounts

    @cached_property
    def private(self) -> PrivateResourceWithRawResponse:
        return PrivateResourceWithRawResponse(self._accounts.private)


class AsyncAccountsResourceWithRawResponse:
    def __init__(self, accounts: AsyncAccountsResource) -> None:
        self._accounts = accounts

    @cached_property
    def private(self) -> AsyncPrivateResourceWithRawResponse:
        return AsyncPrivateResourceWithRawResponse(self._accounts.private)


class AccountsResourceWithStreamingResponse:
    def __init__(self, accounts: AccountsResource) -> None:
        self._accounts = accounts

    @cached_property
    def private(self) -> PrivateResourceWithStreamingResponse:
        return PrivateResourceWithStreamingResponse(self._accounts.private)


class AsyncAccountsResourceWithStreamingResponse:
    def __init__(self, accounts: AsyncAccountsResource) -> None:
        self._accounts = accounts

    @cached_property
    def private(self) -> AsyncPrivateResourceWithStreamingResponse:
        return AsyncPrivateResourceWithStreamingResponse(self._accounts.private)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SearchTextParams", "Pagination"]


class SearchTextParams(TypedDict, total=False):
    input: Required[str]
    """url, text, or base64 input"""

    filters: object
    """Additional filters for the search"""

    group_by_file: bool
    """Whether to group search results by file"""

    input_type: Optional[str]

    modality: Optional[str]

    model_id: Optional[str]

    pagination: Pagination
    """Pagination parameters"""

    source: Optional[str]

    authorization: Annotated[str, PropertyInfo(alias="Authorization")]

    index_id: Annotated[str, PropertyInfo(alias="index-id")]
    """filter by organization"""


class Pagination(TypedDict, total=False):
    page: int
    """Page number"""

    page_size: int
    """Number of items per page"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["Taskresponse"]


class Taskresponse(BaseModel):
    file_id: str

    status: Literal["DONE", "FAILED", "PROCESSING", "DOWNLOADING", "INITIALIZING"]

    task_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import strip_not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["ReadResource", "AsyncReadResource"]


class ReadResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ReadResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return ReadResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ReadResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return ReadResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Test

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/read/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncReadResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncReadResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/mixpeek/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncReadResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncReadResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/mixpeek/python-client#with_streaming_response
        """
        return AsyncReadResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        authorization: str | NotGiven = NOT_GIVEN,
        index_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Test

        Args:
          index_id: filter by organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "Authorization": authorization,
                    "index-id": index_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/read/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class ReadResourceWithRawResponse:
    def __init__(self, read: ReadResource) -> None:
        self._read = read

        self.create = to_raw_response_wrapper(
            read.create,
        )


class AsyncReadResourceWithRawResponse:
    def __init__(self, read: AsyncReadResource) -> None:
        self._read = read

        self.create = async_to_raw_response_wrapper(
            read.create,
        )


class ReadResourceWithStreamingResponse:
    def __init__(self, read: ReadResource) -> None:
        self._read = read

        self.create = to_streamed_response_wrapper(
            read.create,
        )


class AsyncReadResourceWithStreamingResponse:
    def __init__(self, read: AsyncReadResource) -> None:
        self._read = read

        self.create = async_to_streamed_response_wrapper(
            read.create,
        )
